# Ververser Example 2: Game Class

Building on the previous example, 
this example illustrates how such a class can be defined and called from the ververser entrypoints in the main script. 
The differences are in _content/main.py_